@@ -25,26 +25,32 @@
 #include "box_data_list.h"
 #include "box_data_details.h"
 
-/**
-  *@author Murray Cumming
-  */
-
 class Notebook_Data : public Notebook_Glom
 {
 public: 
   Notebook_Data();
   virtual ~Notebook_Data();
-  
-  virtual void init_db_details(const Glib::ustring& strDatabaseName, const Glib::ustring& strTableName, const Glib::ustring& strWhereClause = "");
+
+  //Create the layout for the database structure, and fill it with data.
+  virtual void init_db_details(const Glib::ustring& strTableName, const Glib::ustring& strWhereClause = Glib::ustring());
 
   virtual void select_page_for_find_results(); //Details for 1, List for > 1.
 
   virtual void do_menu_developer_layout(); //override
-  
+  virtual void do_menu_file_print(); //override
+
+  enum dataview
+  {
+    DATA_VIEW_Details,
+    DATA_VIEW_List
+  };
+
+  virtual dataview get_current_view() const;
+
 protected:
 
   //Signal handlers:
-  virtual void on_Details_user_requested_details(Gnome::Gda::Value primary_key_value);
+  virtual void on_list_user_requested_details(Gnome::Gda::Value primary_key_value);
   virtual void on_Details_user_requested_related_details(Glib::ustring strTableName, Gnome::Gda::Value primary_key_value);
 
   //Member widgets:
