@@ -20,7 +20,7 @@
 
 #include "box_tables.h"
 #include <bakery/App/App_Gtk.h> //For util_bold_message().
-#include <libintl.h>
+#include <glibmm/i18n.h>
 
 Box_Tables::Box_Tables(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade)
 : Box_DB(cobject),
@@ -95,25 +95,26 @@ void Box_Tables::fill_from_database()
 
   const bool editable = developer_mode;
   const bool visible_extras = developer_mode;
-  m_colTableName = m_AddDel.add_column(gettext("Tables"), AddDelColumnInfo::STYLE_Text, editable, visible_extras);
-  m_colHidden = m_AddDel.add_column(gettext("Hidden"), AddDelColumnInfo::STYLE_Boolean, editable, visible_extras);
-  m_colTitle =  m_AddDel.add_column(gettext("Title"), AddDelColumnInfo::STYLE_Text, editable, true);
-  m_colDefault =  m_AddDel.add_column(gettext("Default"), AddDelColumnInfo::STYLE_Boolean,  editable, visible_extras);
+  m_colTableName = m_AddDel.add_column(_("Tables"), AddDelColumnInfo::STYLE_Text, editable, visible_extras);
+  m_colHidden = m_AddDel.add_column(_("Hidden"), AddDelColumnInfo::STYLE_Boolean, editable, visible_extras);
+  m_colTitle =  m_AddDel.add_column(_("Title"), AddDelColumnInfo::STYLE_Text, editable, true);
+  m_colDefault =  m_AddDel.add_column(_("Default"), AddDelColumnInfo::STYLE_Boolean,  editable, visible_extras);
 
 
-  //gettext("Server: ") +  m_strServerName + ", " + 
-  //Glib::ustring strTitle = Glib::ustring("<b>") + gettext("Tables from Database: ") + get_database_name() + "");
+  //_("Server: ") +  m_strServerName + ", " + 
+  //Glib::ustring strTitle = Glib::ustring("<b>") + _("Tables from Database: ") + get_database_name() + "");
   //m_pLabelFrameTitle->set_markup(strTitle);
 
   //Get the list of hidden tables:
 
   Document_Glom::type_listTableInfo listTablesDocument;
-  if(m_pDocument)
+  Document_Glom* document = get_document();
+  if(document)
   {
-    listTablesDocument = m_pDocument->get_tables();
+    listTablesDocument = document->get_tables();
   }
   else
-    g_warning("Box_Tables::fill_from_database(): m_pDocument is null");
+    g_warning("Box_Tables::fill_from_database(): document is null");
 
   //Get the list of tables in the database, from the server:
   sharedptr<SharedConnection> sharedconnection = connect_to_server();
@@ -173,7 +174,7 @@ void Box_Tables::fill_from_database()
 void Box_Tables::on_adddel_Add(const Gtk::TreeModel::iterator& row)
 {
   //TODO: Handle cell renderer changes to prevent illegal table names (e.g. starting with numbers.)"
-  
+
   Glib::ustring table_name = m_AddDel.get_value(row, m_colTableName);
   if(!table_name.empty())
   {
@@ -193,23 +194,26 @@ void Box_Tables::on_adddel_Add(const Gtk::TreeModel::iterator& row)
     table_info.m_name = table_name;
     table_info.m_title = util_title_from_string( table_name ); //Start with a title that might be appropriate.
     fill_table_row(row, table_info);
-    
+
     //Save the field information directly into the database, because we can not get all the correct information from the database.
     //Otherwise some information would be forgotten:
     Field field_primary_key;
+    field_primary_key.set_name(primary_key_name);
+    field_primary_key.set_primary_key();
+    field_primary_key.set_auto_increment();
+
     Gnome::Gda::FieldAttributes field_info = field_primary_key.get_field_info();
-    field_info.set_name(primary_key_name);
-    field_info.set_primary_key();
-    field_info.set_auto_increment();
     field_info.set_allow_null(false);
     field_primary_key.set_field_info(field_info);
+
     field_primary_key.set_glom_type(Field::TYPE_NUMERIC);
 
     type_vecFields fields;
     fields.push_back(field_primary_key);
 
-     if(m_pDocument)
-        m_pDocument->set_table_fields(table_name, fields);
+    Document_Glom* document = get_document();
+    if(document)
+        document->set_table_fields(table_name, fields);
 
     save_to_document();
     //fill_from_database(); //We should not modify the model structure in a cellrenderer signal handler.
@@ -228,21 +232,22 @@ void Box_Tables::on_adddel_Delete(const Gtk::TreeModel::iterator& rowStart, cons
 
     if(!table_name.empty())
     {
-      if(m_pDocument)
+      Document_Glom* document = get_document();
+      if(document)
       {
         //Don't open a table that the document does not know about, because we need information from the document:
-        if(!m_pDocument->get_table_is_known(table_name))
+        if(!document->get_table_is_known(table_name))
         {
            //TODO: Do not show tables that are not in the document.
-           Gtk::MessageDialog dialog(gettext("You can not delete this table, because there is no information about this table in the document."));
+           Gtk::MessageDialog dialog(_("You can not delete this table, because there is no information about this table in the document."));
            dialog.set_transient_for(*get_app_window());
            dialog.run();
         }
         else
         {
           //Ask the user to confirm:
-          Glib::ustring strMsg = gettext("Are you sure that you want to delete this table?\nTable name: ") + table_name;
-          Gtk::MessageDialog dialog(Bakery::App_Gtk::util_bold_message(gettext("Delete Table")), true);
+          Glib::ustring strMsg = _("Are you sure that you want to delete this table?\nTable name: ") + table_name;
+          Gtk::MessageDialog dialog(Bakery::App_Gtk::util_bold_message(_("Delete Table")), true);
           dialog.set_secondary_text(strMsg);
           dialog.set_transient_for(*get_app_window());
           int iButtonClicked = dialog.run();
@@ -251,7 +256,7 @@ void Box_Tables::on_adddel_Delete(const Gtk::TreeModel::iterator& rowStart, cons
           if(iButtonClicked == Gtk::RESPONSE_OK)
           {
             Query_execute( "DROP TABLE " + table_name);
-            m_pDocument->remove_table(table_name); //Forget about it in the document too.
+            get_document()->remove_table(table_name); //Forget about it in the document too.
             something_changed = true;
           }
         }
@@ -270,15 +275,16 @@ void Box_Tables::on_adddel_Delete(const Gtk::TreeModel::iterator& rowStart, cons
 void Box_Tables::on_adddel_Edit(const Gtk::TreeModel::iterator& row)
 {
   Glib::ustring table_name = m_AddDel.get_value_key(row);
-  
-  if(m_pDocument)
+
+  Document_Glom* document = get_document();
+  if(document)
   {
     //Don't open a table that the document does not know about, because we need information from the document:
-    if(!m_pDocument->get_table_is_known(table_name))
+    if(!document->get_table_is_known(table_name))
     {
        //TODO: Do not show tables that are not in the document.
-       Gtk::MessageDialog dialog(Bakery::App_Gtk::util_bold_message(gettext("Unknown Table")), true);
-       dialog.set_secondary_text(gettext("You can not open this table, because there is no information about this table in the document."));
+       Gtk::MessageDialog dialog(Bakery::App_Gtk::util_bold_message(_("Unknown Table")), true);
+       dialog.set_secondary_text(_("You can not open this table, because there is no information about this table in the document."));
        dialog.set_transient_for(*get_app_window());
        dialog.run();
     }
@@ -316,8 +322,9 @@ void Box_Tables::save_to_document()
       }
     }
 
-    if(m_pDocument)
-      m_pDocument->set_tables( listTables); //TODO: Don't save all new tables - just the ones already in the document.
+    Document_Glom* document = get_document();
+    if(document)
+      document->set_tables( listTables); //TODO: Don't save all new tables - just the ones already in the document.
   }
 }
 
@@ -345,8 +352,8 @@ void Box_Tables::on_adddel_changed(const Gtk::TreeModel::iterator& row, guint co
       Glib::ustring table_name_new = m_AddDel.get_value(row, m_colTableName);
       if(!table_name.empty() && !table_name_new.empty())
       {
-        Glib::ustring strMsg = gettext("Are you sure that you want to rename this table?");  //TODO: Show old and new names?
-        Gtk::MessageDialog dialog(gettext("Rename Table"));
+        Glib::ustring strMsg = _("Are you sure that you want to rename this table?");  //TODO: Show old and new names?
+        Gtk::MessageDialog dialog(_("Rename Table"));
         dialog.set_secondary_text(strMsg);
         int iButtonClicked = dialog.run();
 
