@@ -25,6 +25,7 @@
 #include "../mode_data/box_data_list_related.h"
 #include "../mode_data/dialog_choose_relationship.h"
 #include <bakery/App/App_Gtk.h> //For util_bold_message().
+#include <glibmm/i18n.h>
 
 FlowTableWithFields::Info::Info()
 : m_first(0),
@@ -40,6 +41,17 @@ FlowTableWithFields::FlowTableWithFields(const Glib::ustring& table_name)
 
 FlowTableWithFields::~FlowTableWithFields()
 {
+  //Remove views. The widgets are deleted automatically because they are managed.
+  for(type_listFields::iterator iter = m_listFields.begin(); iter != m_listFields.end(); ++iter)
+  {
+    View_Composite_Glom* pViewFirst = dynamic_cast<View_Composite_Glom*>(iter->m_first);
+    if(pViewFirst)
+      remove_view(pViewFirst);
+
+   View_Composite_Glom* pViewSecond = dynamic_cast<View_Composite_Glom*>(iter->m_second);
+    if(pViewSecond)
+      remove_view(pViewSecond);
+  }
 }
 
 void FlowTableWithFields::set_table(const Glib::ustring& table_name)
@@ -78,7 +90,7 @@ void FlowTableWithFields::add_layout_item_at_position(const LayoutItem& item, co
       add_field_at_position(*field, m_table_name, add_before);
 
       //Do not allow editing of auto-increment fields:
-      if(field->m_field.get_field_info().get_auto_increment())
+      if(field->m_field.get_auto_increment())
         set_field_editable(*field, false);
       else
         set_field_editable(*field, field->get_editable_and_allowed());
@@ -96,8 +108,10 @@ void FlowTableWithFields::add_layout_item_at_position(const LayoutItem& item, co
           if(found)
           {
             Box_Data_List_Related* portal_box = Gtk::manage(new Box_Data_List_Related);
+            add_view(portal_box); //Give it access to the document, needed to get the layout and fields information.
+
+            portal_box->init_db_details(relationship); //Create the layout
 
-            portal_box->init_db_details(relationship);
             portal_box->set_layout_item(portal->clone(), relationship.get_to_table());
             portal_box->show();
             add(*portal_box, true /* expand */);
@@ -105,7 +119,8 @@ void FlowTableWithFields::add_layout_item_at_position(const LayoutItem& item, co
             m_portals.push_back(portal_box);
             add_layoutwidgetbase(portal_box, add_before);
 
-            add_view(portal_box);
+            //Connect signals:
+            portal_box->signal_record_changed().connect( sigc::mem_fun(*this, &FlowTableWithFields::on_portal_record_changed) );
           }
         }
       }
@@ -171,6 +186,7 @@ void FlowTableWithFields::add_layout_group_at_position(const LayoutGroup& group,
 
     //Connect signal:
     flow_table->signal_field_edited().connect( sigc::mem_fun(*this, &FlowTableWithFields::on_flowtable_entry_edited) );
+    flow_table->signal_related_record_changed().connect( sigc::mem_fun(*this, &FlowTableWithFields::on_flowtable_related_record_changed) );
   }
 }
 
@@ -237,7 +253,7 @@ void FlowTableWithFields::add_field_at_position(const LayoutItem_Field& layoutit
   info.m_field = layoutitem_field;
 
   //Add the entry or checkbox (handled by the DataWidget)
-  DataWidget* pDataWidget = Gtk::manage(new DataWidget(layoutitem_field, table_name) );
+  DataWidget* pDataWidget = Gtk::manage(new DataWidget(layoutitem_field, table_name, get_document()) );
   add_layoutwidgetbase(pDataWidget, add_before);
   add_view(pDataWidget); //So it can get the document.
 
@@ -279,7 +295,16 @@ void FlowTableWithFields::remove_field(const Glib::ustring& id)
       Info info = *iter;
       remove(*(info.m_first));
 
+      View_Composite_Glom* pViewFirst = dynamic_cast<View_Composite_Glom*>(info.m_first);
+      if(pViewFirst)
+        remove_view(pViewFirst);
+
       delete info.m_first;
+
+      View_Composite_Glom* pViewSecond = dynamic_cast<View_Composite_Glom*>(info.m_second);
+      if(pViewSecond)
+        remove_view(pViewSecond);
+
       delete info.m_second; //It is removed at the same time.
 
       iter = m_listFields.erase(iter);
@@ -307,7 +332,8 @@ void FlowTableWithFields::set_field_value(const LayoutItem_Field& field, const G
     Box_Data_List_Related* portal = dynamic_cast<Box_Data_List_Related*>(*iter);
     if(portal)
     {
-      portal->refresh_db_details(value /* foreign key value */, Gnome::Gda::Value() /* TODO */);
+      //g_warning("FlowTableWithFields::set_field_value: foreign_key_value=%s", value.to_string().c_str());
+      portal->refresh_data_from_database(value /* foreign key value */);
     }
   }
 }
@@ -457,7 +483,6 @@ void FlowTableWithFields::change_group(const Glib::ustring& /* id */, const Glib
 
 void FlowTableWithFields::remove_all()
 {
-  //TODO: Release the fields memory, and the portal memory.
   m_listFields.clear();
 
   for(type_sub_flow_tables::iterator iter = m_sub_flow_tables.begin(); iter != m_sub_flow_tables.end(); ++iter)
@@ -471,7 +496,7 @@ void FlowTableWithFields::remove_all()
       delete pSub;
     }
   }
-  
+ 
   m_sub_flow_tables.clear();
 
 
@@ -486,6 +511,18 @@ void FlowTableWithFields::remove_all()
 
   m_list_layoutwidgets.clear();
 
+  //Remove views. The widgets are deleted automatically because they are managed.
+  for(type_listFields::iterator iter = m_listFields.begin(); iter != m_listFields.end(); ++iter)
+  {
+    View_Composite_Glom* pViewFirst = dynamic_cast<View_Composite_Glom*>(iter->m_first);
+    if(pViewFirst)
+      remove_view(pViewFirst);
+
+   View_Composite_Glom* pViewSecond = dynamic_cast<View_Composite_Glom*>(iter->m_second);
+    if(pViewSecond)
+      remove_view(pViewSecond);
+  }
+
   FlowTable::remove_all();
 }
 
@@ -494,6 +531,12 @@ FlowTableWithFields::type_signal_field_edited FlowTableWithFields::signal_field_
   return m_signal_field_edited;
 }
 
+FlowTableWithFields::type_signal_related_record_changed FlowTableWithFields::signal_related_record_changed()
+{
+  return m_signal_related_record_changed;
+}
+
+
 void FlowTableWithFields::on_entry_edited(const Gnome::Gda::Value& value, LayoutItem_Field field)
 {
   m_signal_field_edited.emit(field, value);
@@ -570,6 +613,7 @@ void FlowTableWithFields::get_layout_group(LayoutGroup& group)
       else
       {
         const LayoutItem* pLayoutItem = (*iter)->get_layout_item();
+
         if(pLayoutItem)
           group.add_item(*pLayoutItem);
       }
@@ -620,7 +664,7 @@ void FlowTableWithFields::on_datawidget_layout_item_added(TreeStore_Layout::enum
   else if(item_type == TreeStore_Layout::TYPE_GROUP)
   {
     LayoutGroup layout_item;
-    layout_item.m_title = gettext("New Group");
+    layout_item.m_title = _("New Group");
     add_layout_item_at_position(layout_item, iterAfter);
   }
   else if(item_type == TreeStore_Layout::TYPE_PORTAL)
@@ -665,4 +709,15 @@ void FlowTableWithFields::on_datawidget_layout_item_added(TreeStore_Layout::enum
   signal_layout_changed().emit(); //This should result in a complete re-layout.
 }
 
+void FlowTableWithFields::on_portal_record_changed(const Glib::ustring& relationship_name)
+{
+  signal_related_record_changed().emit(relationship_name);
+}
+
+void FlowTableWithFields::on_flowtable_related_record_changed(const Glib::ustring& relationship_name)
+{
+  //Forward it to the parent:
+  signal_related_record_changed().emit(relationship_name);
+}
+
 
